# SOA125_timings.R
require(SOAs)

## The code below was run with a development version of the R package SOAs
## that used the same functions that are now in the package - however, 
## the default coding for function Spattern (=SOAs::Spattern) was changed, 
## and the unexported functions were renamed, as stated below:

#### The exported function Spattern worked with the complex coding then - 
####      now, one has to use SOAs:::Spattern_complex for the complex coding.
#### The then not exported function SOAs:::Spattern_FFsym2 is now behind 
####      the exported function SOAs::Spattern, as it has been made the default.
#### The then not exported function SOAs:::Spattern_FFsym has been renamed 
####      to SOAs:::Spattern_FFbPoly
#### In each code block, the code that was actually run is followed by 
####      commented lines that hold the code one would have to run for 
####      obtaining analogous timings from version 1.4 of package SOAs.


plan2 <- OSOAs(L25.5.6,el=2,optimize=FALSE)
times25_wtbounded <- matrix(NA,5,3)
dimnames(times25_wtbounded) <- list(maxwt=4:8, contrast=c("complex", "FFsym", "FFsym2"))
pats25_wtbounded_complex <- pats25_wtbounded_FFsym <- pats25_wtbounded_FFsym2 <- vector(mode="list", length = 6)
for (d in 4:8){
  times25_wtbounded[d-3,1] <- system.time(pats25_wtbounded_complex[[d-3]] <- Spattern(plan2, s=5,
                                              maxwt = d))[3]
  times25_wtbounded[d-3,2] <- system.time(pats25_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan2, s=5,
                                                                                 maxwt = d))[3]
  times25_wtbounded[d-3,3] <- system.time(pats25_wtbounded_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan2, s=5,
                                                                                 maxwt = d))[3]
#  times25_wtbounded[d-3,1] <- system.time(pats25_wtbounded_complex[[d-3]] <- SOAs:::Spattern_complex(plan2, s=5,
#                                              maxwt = d))[3]
#  times25_wtbounded[d-3,2] <- system.time(pats25_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan2, s=5,
#                                                                                 maxwt = d))[3]
#  times25_wtbounded[d-3,3] <- system.time(pats25_wtbounded_FFsym2[[d-3]] <- SOAs::Spattern(plan2, s=5,
#                                                                                 maxwt = d))[3]
  print(times25_wtbounded)
}
save(plan2, times25_wtbounded, pats25_wtbounded_complex, pats25_wtbounded_FFsym, pats25_wtbounded_FFsym2, 
     file="SOA125_25_timings_FFsym_wtbounded.RData")

### do not run with maxwt=NULL
plan3 <- OSOAs(L25.5.6,optimize=FALSE)
times125_wtbounded <- matrix(NA,5,3)
dimnames(times125_wtbounded) <- list(maxwt=4:8, contrast=c("complex", "FFsym", "FFsym2"))
pats125_wtbounded_complex <- pats125_wtbounded_FFsym <- pats125_wtbounded_FFsym2 <- vector(mode="list", length = 4)
for (d in 4:8){
  times125_wtbounded[d-3,1] <- system.time(pats125_wtbounded_complex[[d-3]] <- Spattern(plan3, s=5,
                                                                            maxwt = d))[3]
  times125_wtbounded[d-3,2] <- system.time(pats125_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan3, s=5,
                                                                                maxwt = d))[3]
  times125_wtbounded[d-3,3] <- system.time(pats125_wtbounded_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan3, s=5,
                                                                                  maxwt = d))[3]
#  times125_wtbounded[d-3,1] <- system.time(pats125_wtbounded_complex[[d-3]] <- SOAs:::Spattern_complex(plan3, s=5,
#                                                                            maxwt = d))[3]
#  times125_wtbounded[d-3,2] <- system.time(pats125_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan3, s=5,
#                                                                                maxwt = d))[3]
#  times125_wtbounded[d-3,3] <- system.time(pats125_wtbounded_FFsym2[[d-3]] <- SOAs::Spattern(plan3, s=5,
#                                                                                  maxwt = d))[3]
  print(times125_wtbounded)
  save(plan3, times125_wtbounded, pats125_wtbounded_complex, pats125_wtbounded_FFsym, pats125_wtbounded_FFsym2, 
       file="SOA125_125_timings_FFsym_wtbounded.RData")
}

