# SOA64_timings.R
require(SOAs)

## creating the designs
plan2 <- OSOAs(L16.4.5,el=2,optimize=FALSE)
## a GSOA in 5 columns (SOA would have only 4)
plan3 <- plan2
set.seed(8278)
for (l in 15:0){
  repla <- sample((l*4):((l+1)*4-1))
  for (i in 1:5)
    plan3[which(plan3[,i]==l),i] <- repla
}

## The code below was run with a development version of the R package SOAs
## that used the same functions that are now in the package - however, 
## the default coding for function Spattern (=SOAs::Spattern) was changed, 
## and the unexported functions were renamed, as stated below:

#### The exported function Spattern worked with the complex coding then - 
####      now, one has to use SOAs:::Spattern_complex for the complex coding.
#### The then not exported function SOAs:::Spattern_FFsym2 is now behind 
####      the exported function SOAs::Spattern, as it has been made the default.
#### The then not exported function SOAs:::Spattern_FFsym has been renamed 
####      to SOAs:::Spattern_FFbPoly
#### In each code block, the code that was actually run is followed by 
####      commented lines that hold the code one would have to run for 
####      obtaining analogous timings from version 1.4 of package SOAs.


times16_wtNULL <- matrix(NA,5,3)
dimnames(times16_wtNULL) <- list(dimlim=1:5, coding=c("complex", "FFsym", "FFsym2"))
pats16_wtNULL_complex <- vector(mode="list", length = 6)
pats16_wtNULL_FFsym <- vector(mode="list", length = 6)
pats16_wtNULL_FFsym2 <- vector(mode="list", length = 6)

for (d in 2:5){
  times16_wtNULL[d,2] <- system.time(pats16_wtNULL_FFsym[[d]] <- SOAs:::Spattern_FFsym(plan2, s=4,
                                                                                     maxwt = NULL, maxdim = d))[3]
  times16_wtNULL[d,3] <- system.time(pats16_wtNULL_FFsym2[[d]] <- SOAs:::Spattern_FFsym2(plan2, s=4,
                                                                                     maxwt = NULL, maxdim = d))[3]
  times16_wtNULL[d,1] <- system.time(pats16_wtNULL_complex[[d]] <- Spattern(plan2, s=4,
                                                                            maxwt = NULL, maxdim = d))[3]
#  times16_wtNULL[d,2] <- system.time(pats16_wtNULL_FFsym[[d]] <- SOAs:::Spattern_FFbPoly(plan2, s=4,
#                                                                                     maxwt = NULL, maxdim = d))[3]
#  times16_wtNULL[d,3] <- system.time(pats16_wtNULL_FFsym2[[d]] <- SOAs::Spattern(plan2, s=4,
#                                                                                     maxwt = NULL, maxdim = d))[3]
#  times16_wtNULL[d,1] <- system.time(pats16_wtNULL_complex[[d]] <- SOAs:::Spattern_complex(plan2, s=4,
#                                                                            maxwt = NULL, maxdim = d))[3]
  print(times16_wtNULL)
}
save(pats16_wtNULL_complex, pats16_wtNULL_FFsym, pats16_wtNULL_FFsym2, times16_wtNULL, 
file="runtimes_64runs16levels.RData")

times64_wtNULL <- matrix(NA,5,2)
dimnames(times64_wtNULL) <- list(dimlim=1:5, coding=c("complex", "FFsym"))
pats64_wtNULL_complex <- vector(mode="list", length = 6)
pats64_wtNULL_FFsym <- vector(mode="list", length = 6)
#pats64_wtNULL_FFsym2 <- vector(mode="list", length = 6) ## was not run
for (d in 2:4){
  times64_wtNULL[d,1] <- system.time(pats64_wtNULL_complex[[d]] <- Spattern(plan3, s=4,
                                                                            maxwt = NULL, maxdim = d))[3]
  times64_wtNULL[d,2] <- system.time(pats64_wtNULL_FFsym[[d]] <- SOAs:::Spattern_FFsym(plan3, s=4,
                                                                                       maxwt = NULL, maxdim = d))[3]
#  times64_wtNULL[d,1] <- system.time(pats64_wtNULL_complex[[d]] <- SOAs:::Spattern_complex(plan3, s=4,
#                                                                            maxwt = NULL, maxdim = d))[3]
#  times64_wtNULL[d,2] <- system.time(pats64_wtNULL_FFsym[[d]] <- SOAs:::Spattern_FFbPoly(plan3, s=4,
#                                                                                       maxwt = NULL, maxdim = d))[3]
  print(times64_wtNULL) 
}
save(pats64_wtNULL_complex, pats64_wtNULL_FFsym, times64_wtNULL, 
file="runtimes_64runs64levels_wtNULL.RData")

## now with wt bounded
times16_wtbounded <- matrix(NA,5,3)
dimnames(times16_wtbounded) <- list(maxwt=4:8, coding=c("complex", "FFsym", "FFsym2"))
pats16_wtbounded_complex <- vector(mode="list", length = 6)
pats16_wtbounded_FFsym <- vector(mode="list", length = 6)
pats16_wtbounded_FFsym2 <- vector(mode="list", length = 6)
## for second run, moved complex to last position
for (d in 4:8){
  times16_wtbounded[d-3,2] <- system.time(pats16_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan2, s=4,
                                                                                       maxwt = d))[3]
  times16_wtbounded[d-3,3] <- system.time(pats16_wtbounded_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan2, s=4,
                                                                                         maxwt = d))[3]
  times16_wtbounded[d-3,1] <- system.time(pats16_wtbounded_complex[[d-3]] <- Spattern(plan2, s=4,
                                                                            maxwt = d))[3]
#  times16_wtbounded[d-3,2] <- system.time(pats16_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan2, s=4,
#                                                                                       maxwt = d))[3]
#  times16_wtbounded[d-3,3] <- system.time(pats16_wtbounded_FFsym2[[d-3]] <- SOAs::Spattern(plan2, s=4,
#                                                                                         maxwt = d))[3]
#  times16_wtbounded[d-3,1] <- system.time(pats16_wtbounded_complex[[d-3]] <- SOAs:::Spattern_complex(plan2, s=4,
#                                                                            maxwt = d))[3]
  print(times16_wtbounded)
  save(pats16_wtbounded_complex, pats16_wtbounded_FFsym, pats16_wtbounded_FFsym2, times16_wtbounded, 
  file="runtimes_64runs16levels_wtbounded.RData")
}

times64_wtbounded <- matrix(NA,5,3)
dimnames(times64_wtbounded) <- list(maxwt=4:8, coding=c("complex", "FFsym", "FFsym2"))
pats64_wtbounded_complex <- vector(mode="list", length = 6)
pats64_wtbounded_FFsym <- vector(mode="list", length = 6)
pats64_wtbounded_FFsym2 <- vector(mode="list", length = 6)
## for second run, moved complex to last position
for (d in 4:8){
  times64_wtbounded[d-3,1] <- system.time(pats64_wtbounded_complex[[d-3]] <- Spattern(plan3, s=4,
                                                                            maxwt = d))[3]
  times64_wtbounded[d-3,2] <- system.time(pats64_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan3, s=4,
                                                                                       maxwt = d))[3]
  times64_wtbounded[d-3,3] <- system.time(pats64_wtbounded_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan3, s=4,
                                                                                           maxwt = d))[3]
#  times64_wtbounded[d-3,1] <- system.time(pats64_wtbounded_complex[[d-3]] <- SOAs:::Spattern_complex(plan3, s=4,
#                                                                            maxwt = d))[3]
#  times64_wtbounded[d-3,2] <- system.time(pats64_wtbounded_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan3, s=4,
#                                                                                       maxwt = d))[3]
#  times64_wtbounded[d-3,3] <- system.time(pats64_wtbounded_FFsym2[[d-3]] <- SOAs::Spattern(plan3, s=4,
#                                                                                           maxwt = d))[3]
  print(times64_wtbounded)  ## stored as times64_wtbounded_firstrun
}
save(pats64_wtbounded_complex, pats64_wtbounded_FFsym, times64_wtbounded, 
file="runtimes_64runs64levels_wtbounded.RData")

## now with wt bounded and s=2
times16_wtbounded2 <- matrix(NA,5,3)
dimnames(times16_wtbounded2) <- list(maxwt=4:8, coding=c("complex", "FFsym", "FFsym2"))
pats16_wtbounded2_complex <- vector(mode="list", length = 6)
pats16_wtbounded2_FFsym <- vector(mode="list", length = 6)
pats16_wtbounded2_FFsym2 <- vector(mode="list", length = 6)
## for second run, moved complex to last position
for (d in 4:8){
  times16_wtbounded2[d-3,2] <- system.time(pats16_wtbounded2_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan2, s=2,
                                                                                                 maxwt = d))[3]
  times16_wtbounded2[d-3,3] <- system.time(pats16_wtbounded2_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan2, s=2,
                                                                                                   maxwt = d))[3]
  times16_wtbounded2[d-3,1] <- system.time(pats16_wtbounded2_complex[[d-3]] <- Spattern(plan2, s=2,
                                                                                      maxwt = d))[3]
#  times16_wtbounded2[d-3,2] <- system.time(pats16_wtbounded2_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan2, s=2,
#                                                                                                 maxwt = d))[3]
#  times16_wtbounded2[d-3,3] <- system.time(pats16_wtbounded2_FFsym2[[d-3]] <- SOAs::Spattern(plan2, s=2,
#                                                                                                   maxwt = d))[3]
#  times16_wtbounded2[d-3,1] <- system.time(pats16_wtbounded2_complex[[d-3]] <- SOAs:::Spattern_complex(plan2, s=2,
#                                                                                      maxwt = d))[3]
  print(times16_wtbounded2)
  save(pats16_wtbounded2_complex, pats16_wtbounded2_FFsym, pats16_wtbounded2_FFsym2, times16_wtbounded2, 
  file="runtimes_64runs16levels_wtbounded2.RData")
}

times64_wtbounded2 <- matrix(NA,5,3)
dimnames(times64_wtbounded2) <- list(maxwt=4:8, coding=c("complex", "FFsym", "FFsym2"))
pats64_wtbounded2_complex <- vector(mode="list", length = 6)
pats64_wtbounded2_FFsym <- vector(mode="list", length = 6)
pats64_wtbounded2_FFsym2 <- vector(mode="list", length = 6)
for (d in 4:8){
  times64_wtbounded2[d-3,1] <- system.time(pats64_wtbounded2_complex[[d-3]] <- Spattern(plan3, s=2,
                                                                                      maxwt = d))[3]
  times64_wtbounded2[d-3,2] <- system.time(pats64_wtbounded2_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan3, s=2,
                                                                                                 maxwt = d))[3]
  times64_wtbounded2[d-3,3] <- system.time(pats64_wtbounded2_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan3, s=2,
                                                                                                   maxwt = d))[3]
#  times64_wtbounded2[d-3,1] <- system.time(pats64_wtbounded2_complex[[d-3]] <- SOAs:::Spattern_complex(plan3, s=2,
#                                                                                      maxwt = d))[3]
#  times64_wtbounded2[d-3,2] <- system.time(pats64_wtbounded2_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan3, s=2,
#                                                                                                 maxwt = d))[3]
#  times64_wtbounded2[d-3,3] <- system.time(pats64_wtbounded2_FFsym2[[d-3]] <- SOAs::Spattern(plan3, s=2,
#                                                                                                   maxwt = d))[3]
  print(times64_wtbounded2)  
}
save(pats64_wtbounded2_complex, pats64_wtbounded2_FFsym, times64_wtbounded2, 
file="runtimes_64runs64levels_wtbounded2.RData")

## now with wt bounded by 2d (corresponding to the same stratification as for s=4) and s=2
times16_wtbounded2same4 <- matrix(NA,5,3)
dimnames(times16_wtbounded2same4) <- list(maxwt=4:8, coding=c("complex", "FFsym", "FFsym2"))
pats16_wtbounded2same4_complex <- vector(mode="list", length = 6)
pats16_wtbounded2same4_FFsym <- vector(mode="list", length = 6)
pats16_wtbounded2same4_FFsym2 <- vector(mode="list", length = 6)
for (d in 4:8){
  times16_wtbounded2same4[d-3,2] <- system.time(pats16_wtbounded2same4_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan2, s=2,
                                                                                                   maxwt = 2*d))[3]
  times16_wtbounded2same4[d-3,3] <- system.time(pats16_wtbounded2same4_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan2, s=2,
                                                                                                     maxwt = 2*d))[3]
  times16_wtbounded2same4[d-3,1] <- system.time(pats16_wtbounded2same4_complex[[d-3]] <- Spattern(plan2, s=2,
                                                                                        maxwt = 2*d))[3]
#  times16_wtbounded2same4[d-3,2] <- system.time(pats16_wtbounded2same4_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan2, s=2,
#                                                                                                   maxwt = 2*d))[3]
#  times16_wtbounded2same4[d-3,3] <- system.time(pats16_wtbounded2same4_FFsym2[[d-3]] <- SOAs::Spattern(plan2, s=2,
#                                                                                                     maxwt = 2*d))[3]
#  times16_wtbounded2same4[d-3,1] <- system.time(pats16_wtbounded2same4_complex[[d-3]] <- SOAs:::Spattern_complex(plan2, s=2,
#                                                                                        maxwt = 2*d))[3]
  print(times16_wtbounded2same4)
  save(pats16_wtbounded2same4_complex, pats16_wtbounded2same4_FFsym, pats16_wtbounded2same4_FFsym2, times16_wtbounded2same4, 
  file="runtimes_64runs16levels_wtbounded2same4.RData")
}

times64_wtbounded2same4 <- matrix(NA,5,3)
dimnames(times64_wtbounded2same4) <- list(maxwt=4:8, coding=c("complex", "FFsym", "FFsym2"))
pats64_wtbounded2same4_complex <- vector(mode="list", length = 6)
pats64_wtbounded2same4_FFsym <- vector(mode="list", length = 6)
pats64_wtbounded2same4_FFsym2 <- vector(mode="list", length = 6)
for (d in 4:8){
  times64_wtbounded2same4[d-3,1] <- system.time(pats64_wtbounded2same4_complex[[d-3]] <- Spattern(plan3, s=2,
                                                                                        maxwt = 2*d))[3]
  times64_wtbounded2same4[d-3,2] <- system.time(pats64_wtbounded2same4_FFsym[[d-3]] <- SOAs:::Spattern_FFsym(plan3, s=2,
                                                                                                   maxwt = 2*d))[3]
  times64_wtbounded2same4[d-3,3] <- system.time(pats64_wtbounded2same4_FFsym2[[d-3]] <- SOAs:::Spattern_FFsym2(plan3, s=2,
                                                                                                     maxwt = 2*d))[3]
#  times64_wtbounded2same4[d-3,1] <- system.time(pats64_wtbounded2same4_complex[[d-3]] <- SOAs:::Spattern_complex(plan3, s=2,
#                                                                                        maxwt = 2*d))[3]
#  times64_wtbounded2same4[d-3,2] <- system.time(pats64_wtbounded2same4_FFsym[[d-3]] <- SOAs:::Spattern_FFbPoly(plan3, s=2,
#                                                                                                   maxwt = 2*d))[3]
#  times64_wtbounded2same4[d-3,3] <- system.time(pats64_wtbounded2same4_FFsym2[[d-3]] <- SOAs::Spattern(plan3, s=2,
#                                                                                                     maxwt = 2*d))[3]
  print(times64_wtbounded2same4)  
  save(pats64_wtbounded2same4_complex, pats64_wtbounded2same4_FFsym, times64_wtbounded2same4, 
  file="runtimes_64runs64levels_wtbounded2same4.RData")
}
